@@ -6,7 +6,6 @@ from stf_appium_client.tools import find_free_port, assert_tool_exists
 
 
 class AdbServer(Logger):
-    EasyProcess = EasyProcess
     def __init__(self, adb_server: str = None, port: int = None):
         """
         Connect to adb server and open proxy for given port
@@ -59,12 +58,12 @@ class AdbServer(Logger):
         """ Get local adb server port """
         return self._port
 
-    def _execute(self, command: str, timeout: int = 2):
+    def execute(self, command: str, timeout: int = 2) -> EasyProcess:
         """
         Internal execute function
-        :param command: adb command to be execute
+        :param command: adb command to be executed
         :param timeout: command timeout
-        :return: EasyProcess instance which contains stdout, stderr and return_code
+        :return: EasyProcess instance which contains stdout, stderr, return_code, timeout_happened
         """
         port = f"-P {self.port} " if self.port else ""
         cmd = f"adb {port} {command}"
@@ -72,7 +71,7 @@ class AdbServer(Logger):
         my_env = os.environ.copy()
         if "ADB_VENDOR_KEYS" not in my_env:
             my_env["ADB_VENDOR_KEYS"] = "~/.android"
-        response = AdbServer.EasyProcess(cmd, env=my_env).call(timeout=timeout)
+        response = EasyProcess(cmd, env=my_env).call(timeout=timeout)
         self.logger.debug(f'adb stdout: {response.stdout}')
         return response
 
@@ -86,7 +85,7 @@ class AdbServer(Logger):
         self.logger.debug(f'adb({self._adb_server}): connecting')
         try:
             cmd = f"connect {self._adb_server}"
-            response = self._execute(cmd, 10)
+            response = self.execute(cmd, 10)
             stdout = response.stdout
             self.logger.debug(stdout)
             assert response.return_code == 0, f"{response.stderr}"
@@ -102,7 +101,7 @@ class AdbServer(Logger):
         assert self.connected, 'adb is not started'
         try:
             self.logger.debug(f'adb({self.port}): killing service')
-            self._execute('kill-server')
+            self.execute('kill-server')
             self.connected = False
         except AssertionError as error:
             self.logger.error(f'adb kill failed: {error}')
