@@ -6,7 +6,6 @@ from stf_appium_client.Logger import Logger
 
 
 class AppiumClient(Logger):
-    WebDriver = WebDriver
     """"
     Appium client object
     """
@@ -31,7 +30,7 @@ class AppiumClient(Logger):
 
     def start(self):
         assert not self._driver, 'Appium driver already running'
-        self._driver = AppiumClient.WebDriver(command_executor=self._command_executor, **self._kwargs)
+        self._driver = WebDriver(command_executor=self._command_executor, **self._kwargs)
 
     def stop(self):
         assert self._driver, 'Appium driver is not running'
